@@ -61,6 +61,9 @@
 #'   \item{fit_treatment}{Fitted treatment model(s).}
 #'   \item{fit_external}{Fitted external model.}
 #'
+#' @references Wang, G., Levis, A., Steingrimsson, J. and Dahabreh, I. (2024) \emph{Efficient estimation of subgroup treatment effects using multi-source data}, arXiv preprint arXiv:2402.02684.
+#' @references Wang, G., McGrath, S., Lian, Y. and Dahabreh, I. (2024) \emph{CausalMetaR: An R package for performing causally interpretable meta-analyses}, arXiv preprint arXiv:2402.04341.
+#'
 #' @examples
 #' \donttest{
 #' se <- STE_external(
@@ -352,7 +355,7 @@ STE_external <- function(
           psi <- gamma/n_kr * tmp
 
           tmp1[I_xr, ] <- tmp1[I_xr, ] - rep(psi, each = length(I_xr))
-          psi_var <- gamma/n_kr^2 * colSums(rbind(tmp1, tmp2)^2)
+          psi_var <- gamma^2/n_kr^2 * colSums(rbind(tmp1, tmp2)^2)
 
           psi_array_cf[em, , k, r] <- c(psi, psi[1] - psi[2])
           psi_se_array_cf[em, , k, r] <- sqrt(c(psi_var, psi_var[2] + psi_var[2]))
@@ -470,7 +473,7 @@ STE_external <- function(
       psi[em, ] <- gamma/n * tmp
 
       tmp1[I_xr, ] <- tmp1[I_xr, ] - rep(psi[em, ], each = length(I_xr))
-      psi_var[em, ] <- gamma/n^2 * colSums(rbind(tmp1, tmp2)^2)
+      psi_var[em, ] <- gamma^2/n^2 * colSums(rbind(tmp1, tmp2)^2)
     }
 
     psi_array[, ] <- cbind(psi, psi[, 1] - psi[, 2])
