@@ -55,6 +55,9 @@
 #'   \item{fit_treatment}{Fitted treatment model(s).}
 #'   \item{...}{Some additional elements.}
 #'
+#' @references Wang, G., Levis, A., Steingrimsson, J. and Dahabreh, I. (2024) \emph{Efficient estimation of subgroup treatment effects using multi-source data}, arXiv preprint arXiv:2402.02684.
+#' @references Wang, G., McGrath, S., Lian, Y. and Dahabreh, I. (2024) \emph{CausalMetaR: An R package for performing causally interpretable meta-analyses}, arXiv preprint arXiv:2402.04341.
+#'
 #' @examples
 #' \donttest{
 #' si <- STE_internal(
@@ -295,7 +298,7 @@ STE_internal <- function(
             tmp1[I_xs, 1] <- pred_Y1[I_xs] - phi[s, 1]
             tmp1[I_xs, 2] <- pred_Y0[I_xs] - phi[s, 2]
 
-            phi_var[s, ] <- kappa/nrow(X_test)^2 * colSums((tmp1 + tmp2)^2)
+            phi_var[s, ] <- kappa^2/nrow(X_test)^2 * colSums((tmp1 + tmp2)^2)
           }
 
           phi_array_cf[, , em, k, r] <- cbind(phi, phi[, 1] - phi[, 2])
@@ -400,7 +403,7 @@ STE_internal <- function(
         tmp1[I_xs, 1] <- pred_Y1[I_xs] - phi[s, 1]
         tmp1[I_xs, 2] <- pred_Y0[I_xs] - phi[s, 2]
 
-        phi_var[s, ] <- kappa/n^2 * colSums((tmp1 + tmp2)^2)
+        phi_var[s, ] <- kappa^2/n^2 * colSums((tmp1 + tmp2)^2)
       }
       phi_array[, , em] <- cbind(phi, phi[, 1] - phi[, 2])
       phi_se_array[, , em] <- sqrt(cbind(phi_var, phi_var[, 1] + phi_var[, 2]))
